function  displot_gmt_slip(geom, disgeom, slip,x) 
%
% Plot surface projection of the dislocation using GMT psxy
% Paul Segall 1995
%
%    Input: Dislocation Geometry 
%		geom(1) = wid = fault width in dip direction (km)
%		geom(2) = dep = depth of fault bottom (km)
%		geom(3) = dip = dip angle (degrees)
%		geom(4) = latitude of one end (decimal degrees)
%		geom(5) = longitude of one end (decimal degrees)
%		geom(6) = latitude of second end (decimal degrees)
%		geom(7) = longitude of second end (decimal degrees)
%	
%               disgeom(1) = len = fault length in strike direction (km)
%               disgeom(2) = wid = fault width in dip direction (km)
%               disgeom(3) = dep = fault depth (km)
%               disgeom(4) = dip = dip angle (degrees)
%               disgeom(5) = strik =  strike, counter clockwise from E (degrees)
%
[j,k]=size(geom);
i = sqrt(-1);
uo = fopen('temp.gmtlin', 'a');
k=1;
%while k<j+1
	dipr = disgeom(4)*pi/180;
	strkr = disgeom(5)*pi/180;
	%down-dip direction measured from counter-clockwise from Eas
	dipdir = pi - strkr;


	% radius Rp (Polar) and Rm (Meridianal) in meters
	% N = radius of earth, e = eccentricity
	        N = 6378206.4;
	        e = 1./298.257;
	        W = sqrt(1 -e^2*sin(geom(4)*pi/180));
	        Rp = (N/W)*cos(geom(4)*pi/180);
	        Rm = N*(1-e^2)/W^3;
	
	gll = (geom(k,4) + i*geom(k,5));  
	glr = (geom(k,6) + i*geom(k,7));
	
	%factor of 1e3 converts km to meters
  	horproj = disgeom(k,2)*cos(dipr)*1.0e3;
 	 offset = horproj*(i*cos(dipdir)/Rm + sin(dipdir)/Rp)*180/pi;
  	% convert offset from radians to degrees
	
	gul = (geom(k,4) + i*geom(k,5)) + offset;
 	gur = (geom(k,6) + i*geom(k,7)) + offset;
 	du = geom(k,2)-(geom(k,1)*sin(dipr));
  	%
	
	%TA%%plot second line just in from the upper edge
	%TA%offset2 =  0.9*offset;
	%TA%gulm = (geom(4) + i*geom(5)) + offset2;
	%TA%gurm = (geom(6) + i*geom(7)) + offset2;
		
	outline = [geom(k,5), geom(k,4); geom(k,7), geom(k,6); imag(gur), real(gur); imag(gul), real(gul)];
  
	maxslip = min(slip);
	value = slip(x)/maxslip;

% For the GMT Rainbow color palette
	
	if value <= 0.20
		red = 255;
		green = ((value/0.20)*255);
		blue = 000;
	elseif value > 0.20 && value <= 0.40
		red = 255-(((value-0.20)/0.20)*255);
		green = 255;
		blue = 000;
	elseif value > 0.40 && value <= 0.60
		red = 000;
                green = 255;
		blue = (((value-0.40)/0.20)*255);
	elseif value > 0.60 && value <= 0.80
		red = 000;
		green = 255-(((value-0.60)/0.20)*255);
		blue = 255;
       	elseif value > 0.80 && value <= 1.00
		red = (((value-0.80)/0.20)*255);
		green = 000;
		blue = 255;
	end

	%save temp.gmtlin outline -ascii
	%fprintf(uo, '>  \n');
	if	red < 10 
		if green < 10 
			if     blue < 10
			fprintf(uo, '>  -G%1.0f/%1.0f/%1.0f\n',red,green,blue');
			elseif blue < 100
			fprintf(uo, '>  -G%1.0f/%1.0f/%2.0f\n',red,green,blue');
			else
			fprintf(uo, '>  -G%1.0f/%1.0f/%3.0f\n',red,green,blue');
			end
		elseif green < 100
			if     blue < 10
			fprintf(uo, '>  -G%1.0f/%2.0f/%1.0f\n',red,green,blue');
			elseif blue < 100
			fprintf(uo, '>  -G%1.0f/%2.0f/%2.0f\n',red,green,blue');
			else
			fprintf(uo, '>  -G%1.0f/%2.0f/%3.0f\n',red,green,blue');
			end
		else
			if     blue < 10
			fprintf(uo, '>  -G%1.0f/%3.0f/%1.0f\n',red,green,blue');
			elseif blue < 100
			fprintf(uo, '>  -G%1.0f/%3.0f/%2.0f\n',red,green,blue');
			else
			fprintf(uo, '>  -G%1.0f/%3.0f/%3.0f\n',red,green,blue');
			end
		end
	elseif	red < 100
		if green < 10 
			if     blue < 10
			fprintf(uo, '>  -G%2.0f/%1.0f/%1.0f\n',red,green,blue');
			elseif blue < 100
			fprintf(uo, '>  -G%2.0f/%1.0f/%2.0f\n',red,green,blue');
			else
			fprintf(uo, '>  -G%2.0f/%1.0f/%3.0f\n',red,green,blue');
			end
		elseif green < 100
			if     blue < 10
			fprintf(uo, '>  -G%2.0f/%2.0f/%1.0f\n',red,green,blue');
			elseif blue < 100
			fprintf(uo, '>  -G%2.0f/%2.0f/%2.0f\n',red,green,blue');
			else
			fprintf(uo, '>  -G%2.0f/%2.0f/%3.0f\n',red,green,blue');
			end
		else
			if     blue < 10
			fprintf(uo, '>  -G%2.0f/%3.0f/%1.0f\n',red,green,blue');
			elseif blue < 100
			fprintf(uo, '>  -G%2.0f/%3.0f/%2.0f\n',red,green,blue');
			else
			fprintf(uo, '>  -G%2.0f/%3.0f/%3.0f\n',red,green,blue');
			end
		end
	else
		if green < 10 
			if     blue < 10
			fprintf(uo, '>  -G%3.0f/%1.0f/%1.0f\n',red,green,blue');
			elseif blue < 100
			fprintf(uo, '>  -G%3.0f/%1.0f/%2.0f\n',red,green,blue');
			else
			fprintf(uo, '>  -G%3.0f/%1.0f/%3.0f\n',red,green,blue');
			end
		elseif green < 100
			if     blue < 10
			fprintf(uo, '>  -G%3.0f/%2.0f/%1.0f\n',red,green,blue');
			elseif blue < 100
			fprintf(uo, '>  -G%3.0f/%2.0f/%2.0f\n',red,green,blue');
			else
			fprintf(uo, '>  -G%3.0f/%2.0f/%3.0f\n',red,green,blue');
			end
		else
			if     blue < 10
			fprintf(uo, '>  -G%3.0f/%3.0f/%1.0f\n',red,green,blue');
			elseif blue < 100
			fprintf(uo, '>  -G%3.0f/%3.0f/%2.0f\n',red,green,blue');
			else
			fprintf(uo, '>  -G%3.0f/%3.0f/%3.0f\n',red,green,blue');
			end
		end
	end
	
	fprintf(uo, '%12.8f %12.8f\n', outline');
%end
fclose(uo);

